// /src/services/order.service.ts

import http from './http';
import type { Order } from '@/types/Order';

/**
 * ดึงรายการ Order ทั้งหมดจาก backend
 */
export async function listOrders(): Promise<Order[]> {
  const { data } = await http.get('/orders');
  console.log("API Response for Orders:", data); // เช็คข้อมูลที่ได้จาก API
  return data;
}


/**
 * ดึงข้อมูล Order รายการเดียวโดยใช้ OrderID
 */
export async function getOrder(id: number): Promise<Order> {
  const { data } = await http.get(`/orders/${id}`);
  return data;
}

/**
 * สร้าง Order ใหม่
 */
export async function createOrder(payload: Partial<Order>): Promise<Order> {
  const { data } = await http.post('/orders', payload);
  return data;
}

/**
 * อัปเดต Order ตาม OrderID
 */
export async function updateOrder(id: number, payload: Partial<Order>): Promise<Order> {
  const { data } = await http.put(`/orders/${id}`, payload);
  return data;
}

/**
 * ลบ Order ตาม OrderID
 */
export async function deleteOrder(id: number): Promise<void> {
  await http.delete(`/orders/${id}`);
}
