import http from './http';
import type { ProductionTarget } from '@/types/ProductionTarget';

export async function listProductionTargets(): Promise<ProductionTarget[]> {
  const { data } = await http.get('/production-targets');
  return data;
}

export async function getProductionTarget(id: number): Promise<ProductionTarget> {
  const { data } = await http.get(`/production-targets/${id}`);
  return data;
}

export async function createProductionTarget(
  payload: Partial<ProductionTarget>
): Promise<ProductionTarget> {
  const { data } = await http.post('/production-targets', payload);
  return data;
}

export async function updateProductionTarget(
  id: number,
  payload: Partial<ProductionTarget>
): Promise<ProductionTarget> {
  const { data } = await http.put(`/production-targets/${id}`, payload);
  return data;
}

export async function deleteProductionTarget(id: number): Promise<void> {
  await http.delete(`/production-targets/${id}`);
}

export async function editTodayTarget(payload: {
  ProductionTargetID: number;
  ActualProduced: number;
}): Promise<void> {
  await http.post('/production-targets/edit-today', payload);
}